@@ -1,8 +1,10 @@
 Menu.ccd <- function(){
-    putRcmdr("designs", listDesigns2())
-    waehl <- unlist(sapply(designs, function(obj) length(grep("FrF2",design.info(get(obj))$type))>0))
-    if (sum(waehl)) putRcmdr("designs", designs[waehl])
-       else putRcmdr("designs", "")
+    putRcmdr("designs", listDesigns2(type="FrF2"))
+## the next three rows should be omittable
+#    waehl <- unlist(sapply(designs, function(obj) length(grep("FrF2",design.info(get(obj))$type))>0))
+#    if (sum(waehl)) putRcmdr("designs", designs[waehl])
+#       else putRcmdr("designs", "")
+
 #angefangen
 #FrF2-Design Entry mit Knopf fr Erzeugung ber FrF2-Men
 
@@ -103,13 +105,14 @@ onOK <- function(){
 
     ### not yet perfect, especially NULL entries are not possible
     ### for didactic reasons distinguish between usage of default.levels and other?
+    
     if (tclvalue(alphaVar) %in% c("orthogonal","rotatable"))
           command <- paste("ccd.augment(",FrF2Var,
-                  ", alpha=",dQuote(tclvalue(alphaVar)), 
+                  ", alpha=",dQuote(tclvalue(alphaVar)), ", ncenter=", tclvalue(ncenterVar),
                   ",randomize=",as.logical(as.numeric(tclvalue(randomizecbVariable))),
                   ",seed=",tclvalue(seedVar),")") 
     else command <- paste("ccd.augment(",FrF2Var, 
-                  ", alpha=",tclvalue(alphaVar), 
+                  ", alpha=",tclvalue(alphaVar), ", ncenter=", tclvalue(ncenterVar),
                   ",randomize=",as.logical(as.numeric(tclvalue(randomizecbVariable))),
                   ",seed=",tclvalue(seedVar),")") 
 
@@ -238,7 +241,7 @@ onStore <- function(){
 }
 
 onReset <- function(){
-        assign(".stored.designccd",.default.designlhs,pos="RcmdrEnv")
+        assign(".stored.designccd",.default.designccd,pos="RcmdrEnv")
         tkfocus(CommanderWindow())
   tkdestroy(topdes2)
   Menu.ccd()
@@ -271,8 +274,19 @@ onReset <- function(){
  }
 
 newFrF2 <- function(){
+     storeRcmdr()
+     
+     if (!exists(".stored.design2FrF", where="RcmdrEnv")) 
+           hilf <- .default.design2
+           else hilf <- getRcmdr(".stored.design2FrF")
+     hilf$nameVar <- getRcmdr(".stored.designccd")$nameVar
+     hilf$cbInitials[5] <- 0
+     hilf$resVar <- "V+"
+     assign(".stored.design2FrF", hilf,pos="RcmdrEnv")
      closeDialog(window=topdes2)
-     Menu.FrF2level()  
+     Menu.FrF2level()
+     tkmessageBox(message="Continue defining the star portion of the design.",
+             icon="info", type="ok", title="Cube portion was created")
      Menu.ccd()
 }
 
@@ -304,12 +318,12 @@ nameFrame <- ttkframe(tab1)
 #tkgrid(augmentrb, sticky="w")  ## in this case, leave default option from options
 #tkgrid(fromscratchrb, sticky="w")
 
-    designFrame <- ttklabelframe(tab1, text=gettextRcmdr("Determine the cube portion of the central composite design"))
-    designsBox <- variableListBox(parentWindow=designFrame, designs, title=gettextRcmdr("Pick 2-level design for cube portion"),
+    designFrame <- ttklabelframe(tab1, text=gettextRcmdr("Determine the cube portion"))
+    designsBox <- variableListBox(parentWindow=designFrame, designs, title=gettextRcmdr("Pick existing 2-level design"),
         initialSelection=if (is.null(.activeDataSet) || !.activeDataSet %in% designs) NULL 
              else which(.activeDataSet == designs) - 1)
-    designButton <- tkbutton(designFrame, text="Create new cube portion", command=newFrF2)
-    tkgrid(getFrame(designsBox), designButton, sticky="w", padx=10)
+    designButton <- tkbutton(designFrame, text="Create new 2-level design", command=newFrF2)
+    tkgrid(getFrame(designsBox), ttklabel(designFrame, text=" OR "), designButton, sticky="w", padx=10)
     tkconfigure(designButton, takefocus=0)
 
 
@@ -358,7 +372,7 @@ tkgrid(nameFrame, sticky="w", columnspan=4, pady=20)
 tkgrid.configure(helptab1Button, sticky="ne", padx=15)
 #tkgrid(typeradioFrame, sticky="w", columnspan=4)
 
-tkgrid(designFrame, sticky="w",pady=15)
+tkgrid(designFrame, sticky="e",pady=15, columnspan=4)
 
 tkgrid(baseFrame, sticky="nw",columnspan=3)
 
