@@ -11,6 +11,7 @@ justDoItDoE <- function (command)
     }
     else messages.connection <- getRcmdr("messages.connection")
     result <- try(eval(parse(text = command),envir = .GlobalEnv))
-    Rcmdr:::checkWarnings(readLines(messages.connection))
+    ## warnings only, if no error abort
+    if (!class(result)[1]=="try-error") Rcmdr:::checkWarnings(readLines(messages.connection))
     result
 }
